@@ -1,7 +1,5 @@
 from __future__ import absolute_import
 
-import collections
-
 import vertica_python.errors as errors
 
 import vertica_python.vertica.messages as messages
@@ -9,15 +7,12 @@ from vertica_python.vertica.column import Column
 
 
 class Cursor(object):
-
-    def __init__(self, connection, cursor_type=None, row_handler=None):
+    def __init__(self, connection, cursor_type=None):
         self.connection = connection
         self.cursor_type = cursor_type
-        self.row_handler = row_handler
         self._closed = False
 
         self.last_execution = None
-        self.buffered_rows = collections.deque()
         self.error = None
 
         #
@@ -62,17 +57,31 @@ class Cursor(object):
                 raise errors.Error("Argument 'parameters' must be dict or tuple")
 
         self.rowcount = 0
-        self.buffered_rows = collections.deque()
+        if self.last_execution:
+            # ToDo: can just empty the message buffer in connection if easy to do
+            self.connection.reset_connection()
         self.last_execution = operation
         self.connection.write(messages.Query(operation))
 
-        self.fetch_rows()
+        # Fetch the schema
+        message = self.connection.read_message()
+        if isinstance(message, messages.ErrorResponse):
+            raise errors.QueryError.from_error_response(message, self.last_execution)
+        elif not isinstance(message, messages.RowDescription):
+            print("Message type: {0}".format(type(message)))
+            print(message)
+            raise errors.QueryError("Unexpected message type", self.last_execution)
+        self.description = map(lambda fd: Column(fd), message.fields)
 
-        if self.error is not None:
-            raise self.error
-
-    def executemany(self, operation, seq_of_parameters):
-        raise errors.NotSupportedError('Cursor.executemany() is not implemented')
+    def iterate(self):
+        while True:
+            message = self.connection.read_message()
+            if isinstance(message, messages.DataRow):
+                self.rowcount += 1
+                yield self.row_formatter(message)
+            else:
+                # REVIEW: any other case should we check?
+                break
 
     def fetchone(self):
         return self.get_one_row()
@@ -99,9 +108,6 @@ class Cursor(object):
             results.append(row)
         return results
 
-    def nextset(self):
-        raise errors.NotSupportedError('Cursor.nextset() is not implemented')
-
     def setinputsizes(self):
         pass
 
@@ -124,8 +130,9 @@ class Cursor(object):
 
         while True:
             message = self.connection.read_message()
-            self._process_message(message=message)
-            if isinstance(message, messages.ReadyForQuery):
+            if isinstance(message, messages.ErrorResponse):
+                raise errors.QueryError.from_error_response(message, self.last_execution)
+            elif isinstance(message, messages.ReadyForQuery):
                 break
             elif isinstance(message, messages.CopyInResponse):
                 # write stuff
@@ -133,13 +140,9 @@ class Cursor(object):
                     self.connection.write(messages.CopyData(line))
                 self.connection.write(messages.CopyDone())
 
-        if self.error is not None:
-            raise self.error
-
     def copy_string(self, sql, data):
         self._copy_internal(sql, [data])
 
-
     def copy_file(self, sql, data, decoder=None):
         if decoder is None:
             self._copy_internal(sql, data)
@@ -155,48 +158,12 @@ class Cursor(object):
         return self._closed or self.connection.closed()
 
     def get_one_row(self):
-        if len(self.buffered_rows) >= 1:
-            return self.buffered_rows.popleft()
-
-        return None
-
-    def fetch_rows(self):
-        while True:
-            message = self.connection.read_message()
-            self._process_message(message=message)
-            if isinstance(message, messages.ReadyForQuery):
-                break
-
-    def _process_message(self, message):
-        if isinstance(message, messages.ErrorResponse):
-            # what am i doing with self.error?
-            self.error = errors.QueryError.from_error_response(message, self.last_execution)
-        elif isinstance(message, messages.EmptyQueryResponse):
-            self.error = errors.EmptyQueryError("A SQL string was expected, but the given string was blank or only contained SQL comments.")
-        elif isinstance(message, messages.CopyInResponse):
-            pass
-        elif isinstance(message, messages.RowDescription):
-            self.set_description(message)
-        elif isinstance(message, messages.DataRow):
-            self._handle_datarow(message)
-        elif isinstance(message, messages.CommandComplete):
-            pass
-#            self.result.tag = message.tag
-        else:
-            self.connection.process_message(message)
-        return None
-
-    # sets column meta data
-    def set_description(self, message):
-        self.description = map(lambda fd: Column(fd), message.fields)
-
-    def _handle_datarow(self, datarow_message):
-        row = self.row_formatter(datarow_message)
-        if self.row_handler:
-            self.row_handler(row)
-        else:
-            self.buffered_rows.append(row)
+        message = self.connection.read_message()
+        if isinstance(message, messages.DataRow):
             self.rowcount += 1
+            return self.row_formatter(message)
+
+        return None
 
     def row_formatter(self, row_data):
         if not self.cursor_type:
@@ -205,7 +172,7 @@ class Cursor(object):
             return self.format_row_as_array(row_data)
         elif self.cursor_type == 'dict':
             return self.format_row_as_dict(row_data)
-        # throw some error
+            # throw some error
 
     def format_row_as_dict(self, row_data):
         return {
@@ -215,4 +182,4 @@ class Cursor(object):
 
     def format_row_as_array(self, row_data):
         return [self.description[idx].convert(value)
-                for idx, value in enumerate(row_data.values)]
+                for idx, value in enumerate(row_data.values)]
\ No newline at end of file
